from setuptools import setup

setup(name='anatta_common',
      version='0.1',
      description='',
      url='https://github.com/kevinslin',
      author='Kevin S Lin',
      author_email='kevinslin8@gmail.com',
      license='MIT',
      packages=['anatta_common'],
      zip_safe=False)
